List of Quizzes

The current version of this file is availible at our wiki-page.

# Quizdrill/List of Quizzes

OpenFacts, the Open Source Knowledge Database

< Quizdrill

Look at the List of all quizzes in Subversion. You can add links to your own quizzes here (that is on the Quizdrill-Wiki). To have your quiz added to quizdrill please submit it to the Patches of our Issuetracker with the category "quiz". Make sure that we can contact you if we have questions (for the later you can also post to the devel-mailinglist).